@@ -2,7 +2,7 @@
  * Copyright © 2006 Eric Jonas <jonas@mit.edu>
  * Copyright © 2006 Antoine Tremblay <hexa00@gmail.com>
  * Copyright © 2010 United States Government, Joshua M. Doe <joshua.doe@us.army.mil>
- * Copyright © 2010-2019 Emmanuel Pacaud <emmanuel@gnome.org>
+ * Copyright © 2010-2019 Emmanuel Pacaud <emmanuel.pacaud@free.fr>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -212,6 +212,7 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 	GstStructure *structure;
 	ArvPixelFormat pixel_format;
 	gint height, width;
+	gint current_height, current_width;
 	int depth = 0, bpp = 0;
 	const GValue *frame_rate = NULL;
 	const char *caps_string;
@@ -231,10 +232,13 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 	structure = gst_caps_get_structure (caps, 0);
 
 	GST_OBJECT_LOCK (gst_aravis);
-	arv_camera_get_region (gst_aravis->camera, NULL, NULL, &width, &height, &error);
+	arv_camera_get_region (gst_aravis->camera, NULL, NULL, &current_width, &current_height, &error);
 	if (error)
 		goto errored;
 
+        width = current_width;
+        height = current_height;
+
 	is_frame_rate_available = arv_camera_is_frame_rate_available (gst_aravis->camera, NULL);
 	is_gain_available = arv_camera_is_gain_available (gst_aravis->camera, NULL);
 	is_gain_auto_available = arv_camera_is_gain_auto_available (gst_aravis->camera, NULL);
@@ -262,7 +266,16 @@ gst_aravis_set_caps (GstBaseSrc *src, GstCaps *caps)
 
 	if (!error) arv_camera_set_pixel_format (gst_aravis->camera, pixel_format, &error);
 	if (!error) arv_camera_set_binning (gst_aravis->camera, gst_aravis->h_binning, gst_aravis->v_binning, &error);
-	if (!error) arv_camera_set_region (gst_aravis->camera, gst_aravis->offset_x, gst_aravis->offset_y, width, height, &error);
+	if (!error) {
+                if (width != current_width || height != current_height)
+                        arv_camera_set_region (gst_aravis->camera,
+                                               gst_aravis->offset_x, gst_aravis->offset_y,
+                                               width, height, &error);
+                else
+                        arv_camera_set_region (gst_aravis->camera,
+                                               gst_aravis->offset_x, gst_aravis->offset_y,
+                                               -1, -1, &error);
+        }
 
 	if (!error && arv_camera_is_gv_device (gst_aravis->camera)) {
 		if (gst_aravis->packet_delay >= 0) {
@@ -1054,7 +1067,7 @@ gst_aravis_class_init (GstAravisClass * klass)
 		 g_param_spec_int ("packet-size",
 				   "Packet size",
 				   "GigEVision streaming packet size",
-				   ARV_GVSP_PACKET_PROTOCOL_OVERHEAD, 65500, 1500,
+				   ARV_GVSP_PACKET_PROTOCOL_OVERHEAD(FALSE), 65500, 1500,
 				   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property
 		(gobject_class,
@@ -1104,7 +1117,7 @@ gst_aravis_class_init (GstAravisClass * klass)
 					      "Aravis Video Source",
 					      "Source/Video",
 					      "Aravis based source",
-					      "Emmanuel Pacaud <emmanuel@gnome.org>");
+					      "Emmanuel Pacaud <emmanuel.pacaud@free.fr>");
 	gst_element_class_add_pad_template (element_class,
 					    gst_static_pad_template_get (&aravis_src_template));
 
