@@ -56,6 +56,9 @@ typedef struct {
 	ArvGcPropertyNode *is_locked;
 	ArvGcPropertyNode *imposed_access_mode;
 	ArvGcPropertyNode *streamable;
+        ArvGcPropertyNode *is_deprecated;
+        ArvGcPropertyNode *alias;
+        ArvGcPropertyNode *cast_alias;
 
 	guint64 change_count;
 
@@ -106,7 +109,16 @@ arv_gc_feature_node_post_new_child (ArvDomNode *self, ArvDomNode *child)
 				priv->imposed_access_mode = property_node;
 				break;
 			case ARV_GC_PROPERTY_NODE_TYPE_STREAMABLE:
-				priv->streamable = property_node;		/* TODO */
+				priv->streamable = property_node;       	/* TODO */
+				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_IS_DEPRECATED:
+				priv->is_deprecated = property_node;       	/* TODO */
+				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_P_ALIAS:
+				priv->alias = property_node;		        /* TODO */
+				break;
+			case ARV_GC_PROPERTY_NODE_TYPE_P_CAST_ALIAS:
+				priv->alias = property_node;		        /* TODO */
 				break;
 			default:
 				break;
