@@ -376,7 +376,12 @@ _find_frame_data (ArvGvStreamThreadData *thread_data,
                                                  buffer->priv->allocated_size,
                                                  thread_data->scps_packet_size);
         if (n_packets < 1) {
+	        buffer->priv->status = ARV_BUFFER_STATUS_PAYLOAD_NOT_SUPPORTED;
                 arv_stream_push_output_buffer(thread_data->stream, buffer);
+                if (thread_data->callback != NULL)
+                        thread_data->callback (thread_data->callback_data,
+                                               ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE,
+                                               frame->buffer);
                 return NULL;
         }
 
