@@ -107,6 +107,24 @@ integer_test (void)
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "1");
 
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "4", &error);
+        g_assert (error == NULL);
+	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), &error);
+        g_assert (error == NULL);
+	g_assert_cmpint (v_int64, ==, 4);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0xf", &error);
+        g_assert (error == NULL);
+	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), &error);
+        g_assert (error == NULL);
+	g_assert_cmpint (v_int64, ==, 15);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0.4", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
 	arv_gc_integer_set_value (ARV_GC_INTEGER (node), 2, NULL);
 	v_int64 = arv_gc_integer_get_value (ARV_GC_INTEGER (node), NULL);
 	g_assert_cmpint (v_int64, ==, 2);
@@ -308,6 +326,53 @@ boolean_test (void)
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "false");
 
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "True", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, TRUE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "False", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "true", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, TRUE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "false", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "1", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, TRUE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "what", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "2", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0", &error);
+        g_assert (error == NULL);
+	v_boolean = arv_gc_boolean_get_value (ARV_GC_BOOLEAN (node), NULL);
+	g_assert_cmpint (v_boolean, ==, FALSE);
+
 	node = arv_gc_get_node (genicam, "P_RWBoolean");
 	g_assert (ARV_IS_GC_BOOLEAN (node));
 
@@ -367,6 +432,18 @@ float_test (void)
 	v_string = arv_gc_feature_node_get_value_as_string (ARV_GC_FEATURE_NODE (node), NULL);
 	g_assert_cmpstr (v_string, ==, "0.1");
 
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0.4", &error);
+        g_assert (error == NULL);
+	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), &error);
+        g_assert (error == NULL);
+	g_assert_cmpfloat (v_double, ==, 0.4);
+
+        arv_gc_feature_node_set_value_from_string (ARV_GC_FEATURE_NODE (node), "0.4.", &error);
+        g_assert (error != NULL);
+        g_assert (error->domain == ARV_GC_ERROR);
+        g_assert (error->code == ARV_GC_ERROR_INVALID_SYNTAX);
+        g_clear_error (&error);
+
 	arv_gc_float_set_value (ARV_GC_FLOAT (node), 0.2, NULL);
 	v_double = arv_gc_float_get_value (ARV_GC_FLOAT (node), NULL);
 	g_assert_cmpfloat (v_double, ==, 0.2);
@@ -1018,8 +1095,10 @@ create_buffer_with_chunk_data (void)
 
 	buffer = arv_buffer_new (size, NULL);
 	buffer->priv->payload_type = ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA;
+        buffer->priv->has_chunks = TRUE;
+        buffer->priv->received_size = size;
 	buffer->priv->status = ARV_BUFFER_STATUS_SUCCESS;
-	data = (char *) arv_buffer_get_data (buffer, &size);
+	data = (char *) arv_buffer_get_data (buffer, NULL);
 
 	memset ((char *) data, '\0', size);
 
@@ -1281,6 +1360,66 @@ lock_test (void)
 
 	g_object_unref (device);
 }
+
+static void
+access_mode_test (void)
+{
+	ArvDevice *device;
+	ArvGc *genicam;
+	ArvGcNode *node;
+        ArvGcAccessMode access_mode;
+	GError *error = NULL;
+
+	device = arv_fake_device_new ("TEST0", &error);
+	g_assert (ARV_IS_FAKE_DEVICE (device));
+	g_assert (error == NULL);
+
+	genicam = arv_device_get_genicam (device);
+	g_assert (ARV_IS_GC (genicam));
+
+	node = arv_gc_get_node (genicam, "RWRegister_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
+	node = arv_gc_get_node (genicam, "RWRegister_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "RORegister_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "RORegister_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "RWStructEntry_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RW);
+
+	node = arv_gc_get_node (genicam, "RWStructEntry_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "ROStructEntry_ImposedAccessModeRW");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	node = arv_gc_get_node (genicam, "ROStructEntry_ImposedAccessModeRO");
+	g_assert (ARV_IS_GC_FEATURE_NODE (node));
+        access_mode = arv_gc_feature_node_get_actual_access_mode (ARV_GC_FEATURE_NODE (node));
+        g_assert_cmpint (access_mode, ==, ARV_GC_ACCESS_MODE_RO);
+
+	g_object_unref (device);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -1306,6 +1445,7 @@ main (int argc, char *argv[])
 	g_test_add_func ("/genicam/visibility", visibility_test);
 	g_test_add_func ("/genicam/category", category_test);
 	g_test_add_func ("/genicam/lock", lock_test);
+	g_test_add_func ("/genicam/access-mode", access_mode_test);
 
 	result = g_test_run();
 
